@@ -310,15 +310,28 @@ class R3sponse(object):
 			return list(vars(self).keys())
 		def values(self):
 			return list(vars(self).values())
-		def dict(self, serializable=False):
+		def dict(self, serializable=False, json=False):
 			dictionary = {}
 			for key, value in self.items():
 				if serializable:
-					if isinstance(value, object):
-						value = str(value)
-					elif value == "True": value = True
-					elif value == "False": value = False
-					elif value == "None": value = None
+					if isinstance(value, object) and not isinstance(value, dict) and not isinstance(value, list):
+						value = f"{value}"
+					elif isinstance(value, str) or isinstance(value, bool) or value == None:
+						if value in [True, "True", "True".lower()]: 
+							if json:
+								value = "true"
+							else: 
+								value = True
+						elif value in [False, "False", "False".lower()]: 
+							if json:
+								value = "false"
+							else: 
+								value = False
+						elif value in [None, "None", "None".lower()]: 
+							if json:
+								value = "null"
+							else: 
+								value = None
 				dictionary[key] = value
 			return dictionary
 		# assign self variables by dictionary.
@@ -365,19 +378,9 @@ class R3sponse(object):
 			delattr(self, key)
 		# string format.
 		def __str__(self):
-			return json.dumps(self.dict(serializable=True), indent=4) # necessary for str(self)
-			return self.dict(serializable=True) # seems to work for django.
-			if isinstance(self, dict):
-				return json.dumps(self, indent=4)
-			else:
-				return json.dumps(self.dict(), indent=4)
-		def json(self,):
-			return json.dumps(self.dict(serializable=True), indent=4)
-			return self.dict(serializable=True) # seems to work for django.
-			return self.dict(serializable=True)
-			return json.dumps(self.dict(serializable=True), indent=4)
-			return json.dumps(self)
-			return json.dumps(self, default=lambda o: o.__dict__)
+			return self.json(indent=4) # necessary for str(self)
+		def json(self, indent=4):
+			return json.dumps(self.dict(serializable=True, json=True), indent=indent).replace(': "None"', ': null').replace(': "False"', ': false').replace(': "True"', ': true')
 		#def __dict__(self):
 		#	return json.dumps(self.dict(), indent=4)
 
